@@ -128,7 +128,7 @@ class MetasploitModule < Msf::Exploit::Remote
                 "(#{Rex::Socket.addr_ntoa(item[1])})")
             report_note({
               :type => 'PXE.client',
-              :data => item[0].unpack('H2H2H2H2H2H2').join(':')
+              :data => { :client => item[0].unpack('H2H2H2H2H2H2').join(':') }
             })
           end
         rescue ::Interrupt
@@ -156,7 +156,7 @@ class MetasploitModule < Msf::Exploit::Remote
           "(#{Rex::Socket.addr_ntoa(ip)})")
       report_note({
         :type => 'PXE.client',
-        :data => mac.unpack('H2H2H2H2H2H2').join(':')
+        :data => { :client => mac.unpack('H2H2H2H2H2H2').join(':') }
       })
     end
     @dhcp.start
